==> dl.php?src=linea21_1_4.zip: linea21/workshoprep/help.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage workshoprep
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 * 'Workshoprep' (as Workshop Report) module is used by 'Workshop' modules
 */

//////////// Check Inclusion de pages ////////////
if (!function_exists('AuthenthificationProcess')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!HaveRight('workshop')) ReloadIndex('admin');
////////////

$dirbox = $dir . "/help";
?>
<br
	class="brendstep brendstepfooter" />
<div class="headerhelp"><a href="#aideencre"
	title="<?php echo _t('help','title');?>" class="help_ico aideencre"></a>
<div class="help"><a href="#aideencre" class="aideencre" id="aideencre"
	title="<?php echo _t('help','title');?>"><?php echo _t('help','title');?></a>
<div id="aide"><?if ($todo == 'add') {
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshoprep','add');?></p>
<ul>
	<li><?php echo _t('workshoprep','help_add1');?></li>
	<li><?php echo _t('workshoprep','help_add2');?></li>
	<li><?php echo _t('workshoprep','help_add3');?></li>
</ul>

  <?php }
  if ($todo == 'det') {
    ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshoprep','det');?></p>
<ul>
	<li><?php echo _t('workshoprep','help_det1');?></li>
	<li><?php echo _t('workshoprep','help_det2');?></li>
	<li><?php echo _t('workshoprep','help_det3');?></li>
	<li><?php echo _t('workshoprep','help_det4');?></li>
</ul>
    <?
  }
  if ($todo == 'mod') {
    ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshoprep','mod');?></p>
<ul>
	<li><?php echo _t('workshoprep','help_mod1');?></li>
	<li><?php echo _t('workshoprep','help_mod2');?></li>
	<li><?php echo _t('workshoprep','help_mod3');?></li>
</ul>
    <?php }
    if ($todo == 'sup') {
      ?>

<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshoprep','sup');?></p>
<ul>
	<li><?php echo _t('workshoprep','help_sup1');?></li>
</ul>
      <?php }
      include_once(THEME_ADMIN_PATH."footer_content.php");
?>

==> dl.php?src=linea21_1_6.zip: linea21/workshoprep/help.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage workshoprep
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 * 'Workshoprep' (as Workshop Report) module is used by 'Workshop' modules
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight('workshop')) ReloadIndex('admin');
////////////

$dirbox = $dir . "/help";
?>
<br
	class="brendstep brendstepfooter" />
<div class="headerhelp"><a href="#aide-ancre"
	title="<?php echo _t('help','title');?>" class="help_ico aide-ancre"></a>
<div class="help"><a href="#aide-ancre" class="aide-ancre" id="aide-ancre"
	title="<?php echo _t('help','title');?>"><?php echo _t('help','title');?></a>
<div id="aide"><?php if ($todo == 'add') {
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshoprep','add');?></p>
<ul>
	<li><?php echo _t('workshoprep','help_add1');?></li>
	<li><?php echo _t('workshoprep','help_add2');?></li>
	<li><?php echo _t('workshoprep','help_add3');?></li>
</ul>

  <?php }
  if ($todo == 'det') {
    ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshoprep','det');?></p>
<ul>
	<li><?php echo _t('workshoprep','help_det1');?></li>
	<li><?php echo _t('workshoprep','help_det2');?></li>
	<li><?php echo _t('workshoprep','help_det3');?></li>
	<li><?php echo _t('workshoprep','help_det4');?></li>
</ul>
    <?php
  }
  if ($todo == 'mod') {
    ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshoprep','mod');?></p>
<ul>
	<li><?php echo _t('workshoprep','help_mod1');?></li>
	<li><?php echo _t('workshoprep','help_mod2');?></li>
	<li><?php echo _t('workshoprep','help_mod3');?></li>
</ul>
    <?php }
    if ($todo == 'sup') {
      ?>

<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshoprep','sup');?></p>
<ul>
	<li><?php echo _t('workshoprep','help_sup1');?></li>
</ul>
      <?php }
      include_once(THEME_ADMIN_PATH."footer_content.php");
?>
